#[non_exhaustive]pub enum WorkflowBudgetReservationOutcome {
NotConfigured,
Reserved,
}Expand description
Outcome of attempting to reserve a tenant budget envelope.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NotConfigured
No aggregate tenant budget is configured.
Reserved
The workflow envelope is durably reserved under the current lease.