#[non_exhaustive]pub enum WorkflowCheckpointPhase {
Ready,
StepInFlight {
step: StepId,
},
Waiting {
step: StepId,
wait: WorkflowWait,
},
ParallelInFlight {
step: StepId,
branches: BTreeMap<StepId, ParallelBranchCheckpoint>,
},
RaceInFlight {
step: StepId,
branches: BTreeMap<StepId, ParallelBranchCheckpoint>,
},
Completed {
outcome: WorkflowOutcome,
},
}Expand description
Persisted workflow execution phase.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Ready
Stable output is ready for the next node.
StepInFlight
One node may have partially executed.
Waiting
The worker lease was released while this node awaits a durable wake.
ParallelInFlight
A parallel node has one or more incomplete branches.
Fields

branches: BTreeMap<StepId, ParallelBranchCheckpoint>Durable branch progress keyed independently of completion order.
RaceInFlight
A first-success race has no durable winner yet, or awaits commit.
Fields

branches: BTreeMap<StepId, ParallelBranchCheckpoint>Durable branch progress keyed independently of completion order.
Completed
The workflow reached a terminal output.
Fields

outcome: WorkflowOutcomeComplete canonical workflow result.