#[non_exhaustive]pub enum WorkflowDisposition {
Completed,
RetryAfter(Duration),
Suspend(WorkflowWait),
Failed(String),
Cancelled,
}Expand description
Durable task disposition accepted from the current lease owner.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Completed
The checkpoint contains a terminal successful outcome.
RetryAfter(Duration)
Return the task to the queue after a store-relative delay.
Suspend(WorkflowWait)
Release the worker while waiting for time or an external signal.
Failed(String)
Stop automatic execution with a safe operator-facing reason.
Cancelled
Stop execution because the task was explicitly cancelled.