#[non_exhaustive]pub enum WorkflowInterruptDecisionOutcome {
Buffered,
WokeWorkflow,
Duplicate,
DeadLettered,
}Expand description
Result of submitting a typed human-review decision.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Buffered
The decision was accepted before the worker committed its wait.
WokeWorkflow
The decision atomically made the suspended workflow claimable.
Duplicate
An identical idempotency identity and decision already existed.
DeadLettered
The request was stale or the workflow had become terminal.