#[non_exhaustive]pub enum WorkflowRemediationCheckpoint {
GenerationReady {
input: Value,
},
GenerationInFlight {
input: Value,
},
ReviewReady {
candidate: Value,
},
ReviewInFlight {
candidate: Value,
},
Approved {
output: Value,
},
Rejected {
candidate: Value,
reason: String,
},
Exhausted {
candidate: Value,
feedback: Value,
},
}Expand description
Durable substate of one repairable workflow node.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
GenerationReady
The next generation input is durable and has not started.
GenerationInFlight
A generation may have partially executed.
ReviewReady
A generated candidate is durable and has not entered review.
ReviewInFlight
Review of a durable candidate may have partially executed.
Approved
Review accepted a durable candidate before the outer node commit.
Rejected
Review permanently rejected a candidate.
Fields
Exhausted
The configured repair limit was exhausted.