#[non_exhaustive]pub enum WorkflowResumePolicy {
RejectAmbiguous,
RetryInterruptedStep,
}Expand description
Recovery behavior for a workflow interrupted inside one node.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
RejectAmbiguous
Reject recovery that could duplicate model cost or external effects.
RetryInterruptedStep
Explicitly retry only the interrupted workflow node.