#[non_exhaustive]pub enum WorkflowReviewError {
InvalidConfiguration(String),
InvalidDecision(String),
FeedbackTooLarge,
InvalidRejectionReason,
Execution(String),
}Expand description
Failure returned by an application-owned output reviewer.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidConfiguration(String)
Reviewer construction or composition was invalid.
InvalidDecision(String)
A reviewer returned a structurally valid but semantically inconsistent decision.
FeedbackTooLarge
Reviewer feedback exceeded the durable checkpoint limit.
InvalidRejectionReason
A rejection reason was blank or exceeded its durable limit.
Execution(String)
The reviewer could not evaluate the candidate.