#[non_exhaustive]pub enum WorkflowSignalOutcome {
Buffered,
WokeWorkflow,
Duplicate,
DeadLettered,
}Expand description
Result of an idempotent signal publication.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Buffered
The signal was buffered before its matching wait was installed.
WokeWorkflow
The signal atomically made its waiting workflow claimable.
Duplicate
An identical signal identity and payload had already been accepted.
DeadLettered
The target was already terminal or the signal lost its durable timeout race.