#[non_exhaustive]pub enum WorkflowStoreErrorKind {
InvalidInput,
NotFound,
Conflict,
LeaseLost,
AdmissionDenied,
TenantMismatch,
Storage,
}Expand description
Stable workflow-store failure category.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidInput
Input violated a domain invariant.
NotFound
The requested task does not exist.
Conflict
A create-only operation found an existing task.
LeaseLost
The caller no longer owns the current unexpired lease.
AdmissionDenied
A tenant admission limit prevented the operation.
TenantMismatch
The supplied tenant does not own the requested resource.
Storage
The backing store failed.