#[non_exhaustive]pub enum WorkflowWorkerOutcome {
Idle,
Completed {
checkpoint_id: CheckpointId,
outcome: WorkflowOutcome,
},
Retried {
checkpoint_id: CheckpointId,
},
Suspended {
checkpoint_id: CheckpointId,
},
Failed {
checkpoint_id: CheckpointId,
},
DefinitionUnavailable {
checkpoint_id: CheckpointId,
},
LeaseLost {
checkpoint_id: CheckpointId,
},
}Expand description
Result of one worker claim-and-execute cycle.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Idle
No eligible task was available.
Completed
A task completed and its terminal checkpoint is durable.
Fields

checkpoint_id: CheckpointIdStable workflow identity.

outcome: WorkflowOutcomeCanonical workflow outcome.
Retried
Execution failed and the task was returned to the queue.
Fields

checkpoint_id: CheckpointIdStable workflow identity.
Suspended
Execution durably released its lease while waiting for a wake condition.
Fields

checkpoint_id: CheckpointIdStable workflow identity.
Failed
Execution failed and the task became terminal.
Fields

checkpoint_id: CheckpointIdStable workflow identity.
The claimed workflow definition is not installed on this worker.
LeaseLost
Heartbeat or fenced persistence proved ownership was lost or uncertain.
Fields

checkpoint_id: CheckpointIdStable workflow identity.