pub struct ParallelBranch { /* private fields */ }Expand description
One explicitly budgeted branch of a parallel workflow node.
Implementations
Sourceimpl ParallelBranch
impl ParallelBranch
Sourcepub fn step<S>(
id: impl Into<String>,
step: S,
capabilities: CapabilitySet,
reservation: Usage,
) -> Selfwhere
S: WorkflowStep + 'static,
pub fn step<S>(
id: impl Into<String>,
step: S,
capabilities: CapabilitySet,
reservation: Usage,
) -> Selfwhere
S: WorkflowStep + 'static,
Creates a custom parallel branch with an explicit resource reservation.