pub struct WorkflowDefinition { /* private fields */ }Expand description
Executable workflow definition and its root authority policy.
Implementations
Sourceimpl WorkflowDefinition
impl WorkflowDefinition
Sourcepub fn new(
workflow: Arc<Workflow>,
budget: Budget,
capabilities: CapabilitySet,
) -> Self
pub fn new( workflow: Arc<Workflow>, budget: Budget, capabilities: CapabilitySet, ) -> Self
Registers a workflow with explicit root budget and authority.
Sourcepub fn with_journal(self, journal: Arc<dyn Journal>) -> Self
pub fn with_journal(self, journal: Arc<dyn Journal>) -> Self
Attaches a durable event journal to worker-created Runs.
Sourcepub const fn with_resume_policy(self, policy: WorkflowResumePolicy) -> Self
pub const fn with_resume_policy(self, policy: WorkflowResumePolicy) -> Self
Selects explicit interrupted-step recovery authority.
Sourcepub const fn with_failure_policy(self, policy: WorkflowFailurePolicy) -> Self
pub const fn with_failure_policy(self, policy: WorkflowFailurePolicy) -> Self
Selects how ordinary workflow execution failures affect the task.