pub struct WorkflowTaskCleanupSupervisorConfig { /* private fields */ }Expand description
Validated bounds and timing for automatic terminal Task cleanup.
Implementations
Sourceimpl WorkflowTaskCleanupSupervisorConfig
impl WorkflowTaskCleanupSupervisorConfig
Sourcepub fn new(
shard: WorkflowTaskCleanupShard,
retention: WorkflowTaskRetention,
lease_duration: LeaseDuration,
heartbeat_interval: Duration,
) -> Result<Self, WorkflowStoreError>
pub fn new( shard: WorkflowTaskCleanupShard, retention: WorkflowTaskRetention, lease_duration: LeaseDuration, heartbeat_interval: Duration, ) -> Result<Self, WorkflowStoreError>
Creates conservative cleanup timing and work bounds.
Errors
Rejects a zero heartbeat or one not shorter than the lease.
Sourcepub const fn with_work_limits(
self,
discovery_limit: WorkflowTenantListLimit,
max_concurrency: NonZeroUsize,
cleanup_limit: WorkflowTaskCleanupLimit,
max_batches_per_tenant: NonZeroU32,
) -> Self
pub const fn with_work_limits( self, discovery_limit: WorkflowTenantListLimit, max_concurrency: NonZeroUsize, cleanup_limit: WorkflowTaskCleanupLimit, max_batches_per_tenant: NonZeroU32, ) -> Self
Sets bounded discovery, concurrency, batch size, and work per claim.
Sourcepub fn with_intervals(
self,
scan_interval: Duration,
error_backoff: Duration,
) -> Result<Self, WorkflowStoreError>
pub fn with_intervals( self, scan_interval: Duration, error_backoff: Duration, ) -> Result<Self, WorkflowStoreError>