pub struct WorkflowTaskTombstoneArchiveError { /* private fields */ }Expand description
Safe archive adapter failure.
Implementations
Sourceimpl WorkflowTaskTombstoneArchiveError
impl WorkflowTaskTombstoneArchiveError
Sourcepub fn new(message: impl Into<String>) -> Self
pub fn new(message: impl Into<String>) -> Self
Creates a bounded safe archive failure with the fallback classification.
Sourcepub fn with_kind(
kind: WorkflowTaskTombstoneArchiveErrorKind,
message: impl Into<String>,
) -> Self
pub fn with_kind( kind: WorkflowTaskTombstoneArchiveErrorKind, message: impl Into<String>, ) -> Self
Creates a bounded safe archive failure with a stable classification.
Sourcepub const fn kind(&self) -> WorkflowTaskTombstoneArchiveErrorKind
pub const fn kind(&self) -> WorkflowTaskTombstoneArchiveErrorKind
Returns the stable failure class without exposing provider detail.